<?php
	/**
	 * Copyright (c) 2008- Samuli Jrvel
	 *
	 * All rights reserved. This program and the accompanying materials
	 * are made available under the terms of the Eclipse Public License v1.0
	 * which accompanies this distribution, and is available at
	 * http://www.eclipse.org/legal/epl-v10.html. If redistributing this code,
	 * this entire header must remain intact.
	 */
	
	/* For configuration instructions, see ReadMe.txt or wiki page at http://code.google.com/p/mollify/wiki/Installation */
	
	/* Default permission: "RW" = Read/write, "RO" = Read-only (default if omitted) */
	
	$DEFAULT_PERMISSION = "RO";
	
	$PUBLISHED_FOLDERS = array(
		"r1" => array("name" => "Folder A", "path" => "/foo/bar"),
		"r2" => array("name" => "Folder B", "path" => "/foo/bay")
	);
	
	$SETTINGS = array(
		"timezone" => "Europe/Helsinki"	// change this to match your timezone
	);
	
?>